clean_annotation: Clean annotation text by removing prefixes and extra...

View source: R/consensus_annotation.R

clean_annotationR Documentation

Clean annotation text by removing prefixes and extra whitespace

Description

Clean annotation text by removing prefixes and extra whitespace

Usage

clean_annotation(annotation)

mLLMCelltype documentation built on May 11, 2026, 9:06 a.m.