get_initial_predictions: Get initial predictions from all models

View source: R/consensus_annotation.R

get_initial_predictionsR Documentation

Get initial predictions from all models

Description

This function retrieves initial cell type predictions from all specified models. It is an internal helper function used by the interactive_consensus_annotation function.

Usage

get_initial_predictions(
  input,
  tissue_name,
  models,
  api_keys,
  top_gene_count,
  base_urls = NULL
)

mLLMCelltype documentation built on May 11, 2026, 9:06 a.m.