mLLMCelltype-package: mLLMCelltype: Cell Type Annotation Using Large Language...

mLLMCelltype-packageR Documentation

mLLMCelltype: Cell Type Annotation Using Large Language Models

Description

Automated cell type annotation for single-cell RNA sequencing data using consensus predictions from multiple large language models. Integrates with Seurat objects and provides uncertainty quantification for annotations. Supports various LLM providers including OpenAI, Anthropic, and Google. For details see Yang et al. (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1101/2025.04.10.647852")}.

Author(s)

Maintainer: Chen Yang cafferychen777@tamu.edu [copyright holder]

See Also

Useful links:


mLLMCelltype documentation built on May 11, 2026, 9:06 a.m.