| get_api_key | R Documentation |
This file contains utility functions for managing API keys and related operations. Get API key for a specific model
get_api_key(model, api_keys)
model |
Model name to get API key for |
api_keys |
Named list of API keys with provider or model names as keys |
This function retrieves the appropriate API key for a given model by first checking the provider name and then the model name in the provided API keys list.
API key string for the specified model
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.