View source: R/consensus_annotation.R
| get_initial_predictions | R Documentation |
This function retrieves initial cell type predictions from all specified models. It is an internal helper function used by the interactive_consensus_annotation function.
get_initial_predictions(
input,
tissue_name,
models,
api_keys,
top_gene_count,
base_urls = NULL
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.