| mLLMCelltype-package | R Documentation |
Automated cell type annotation for single-cell RNA sequencing data using consensus predictions from multiple large language models. Integrates with Seurat objects and provides uncertainty quantification for annotations. Supports various LLM providers including OpenAI, Anthropic, and Google. For details see Yang et al. (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1101/2025.04.10.647852")}.
Maintainer: Chen Yang cafferychen777@tamu.edu [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.