View source: R/compare_model_predictions.R
| standardize_cell_type_names | R Documentation |
This function takes predictions from multiple models and standardizes the cell type nomenclature to ensure consistent naming across different models' outputs.
standardize_cell_type_names(
predictions,
models,
api_keys,
standardization_model = "claude-sonnet-4-6",
base_urls = NULL
)
With provider names as keys: list("openai" = "sk-...", "anthropic" = "sk-ant-...", "openrouter" = "sk-or-...")
With model names as keys: list("gpt-5.5" = "sk-...", "claude-sonnet-4-6" = "sk-ant-...")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.